@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -50,6 +50,7 @@
 #include <libxfce4util/libxfce4util.h>
 
 #include "xfconf-daemon.h"
+#include "xfconf-backend-factory.h"
 
 #define DEFAULT_BACKEND  "xfce-perchannel-xml"
 
@@ -66,7 +67,7 @@ static void
 sighandler(int sig)
 {
     guint32 sigstate;
-    gint avoid_gcc_warning;
+    gint avoid_gcc_warning G_GNUC_UNUSED;
     
     switch(sig) {
         case SIGUSR1:
@@ -77,7 +78,7 @@ sighandler(int sig)
             sigstate = SIGNAL_QUIT;
             break;
     }
-    
+
     avoid_gcc_warning = write(signal_pipe[1], &sigstate, sizeof(sigstate));
 }
 
@@ -157,7 +158,10 @@ main(int argc,
     
     g_set_application_name(_("Xfce Configuration Daemon"));
     g_set_prgname(G_LOG_DOMAIN);
+
+#if !GLIB_CHECK_VERSION(2,36,0)
     g_type_init();
+#endif
     
     opt_ctx = g_option_context_new(NULL);
     g_option_context_set_translation_domain(opt_ctx, PACKAGE);
@@ -231,6 +235,8 @@ main(int argc,
     g_main_loop_run(mloop);
     
     g_object_unref(G_OBJECT(xfconfd));
+
+    xfconf_backend_factory_cleanup();
     
     if(signal_watch) {
         g_source_remove(signal_watch);
